/**
 * Convert option.
 *
 * So far only the format type
 *
 * @stability stable
 */
export interface ConvertOptions {
    /**
     * @stability stable
     */
    readonly formatType: FormatType;
}
/**
 * Format type to convert the ALPS spec into.
 *
 * @stability stable
 */
export declare enum FormatType {
    /**
     * @stability stable
     */
    S = 0,
    /**
     * @stability stable
     */
    SDL = 1,
    /**
     * @stability stable
     */
    A = 2,
    /**
     * @stability stable
     */
    ASYNC = 3,
    /**
     * @stability stable
     */
    ASYNCAPI = 4,
    /**
     * @stability stable
     */
    O = 5,
    /**
     * @stability stable
     */
    OAS = 6,
    /**
     * @stability stable
     */
    OPEN = 7,
    /**
     * @stability stable
     */
    OPENAPI = 8,
    /**
     * @stability stable
     */
    P = 9,
    /**
     * @stability stable
     */
    PROTO = 10,
    /**
     * @stability stable
     */
    J = 11,
    /**
     * @stability stable
     */
    JSON = 12,
    /**
     * @stability stable
     */
    W = 13,
    /**
     * @stability stable
     */
    WSDL = 14,
    /**
     * @stability stable
     */
    SOAP = 15
}
/**
 * @stability stable
 */
export declare class Alps {
    /**
     * Converts an ALPS spec JSON object into a specified API like openApi or graph ql schema.
     *
     * @param alpsDocument The ALPS document.
     * @param options Options for the convertion.
     * @returns the requested api in string format
     * @stability stable
     */
    static unified(alpsDocument: any, options?: ConvertOptions): string;
    /**
     * loads the ALPS document.
     *
     * @param path ALPS spec file path.
     * @stability stable
     */
    static loadYaml(path: string): any;
    /**
     * @stability stable
     */
    static spec(spec: AlpsSpec): AlpsSpec;
}
/**
 * @stability stable
 */
export interface AlpsSpec {
    /**
     * @stability stable
     */
    readonly alps: AlpsDef;
}
/**
 * @stability stable
 */
export interface AlpsDef {
    /**
     * can be any string e.g.: 1.0.
     *
     * @stability stable
     */
    readonly version: string;
    /**
     * @stability stable
     */
    readonly doc: DocDef;
    /**
     * @stability stable
     */
    readonly ext: ExtDef[];
    /**
     * @stability stable
     */
    readonly descriptor: DescriptorDefOuter[];
}
/**
 * @stability stable
 */
export interface DocDef {
    /**
     * @stability stable
     */
    readonly value: string;
}
/**
 * @stability stable
 */
export interface ExtDef {
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * @stability stable
     */
    readonly name: string;
    /**
     * @stability stable
     */
    readonly value: string;
    /**
     * @stability stable
     */
    readonly tags: string;
}
/**
 * @stability stable
 */
export interface DescriptorDefOuter {
    /**
     * @stability stable
     */
    readonly id: string;
    /**
     * @stability stable
     */
    readonly type: string;
    /**
     * @stability stable
     */
    readonly rt?: string;
    /**
     * @stability stable
     */
    readonly text: string;
    /**
     * @stability stable
     */
    readonly tags?: string;
    /**
     * @stability stable
     */
    readonly descriptor?: DescriptorDefInner[];
}
/**
 * @stability stable
 */
export interface DescriptorDefInner {
    /**
     * @stability stable
     */
    readonly href: string;
}
